@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1202';
 
 use Moo;
 use Music::Chord::Note;
@@ -247,7 +247,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1201
+version 0.1202
 
 =head1 SYNOPSIS
 
@@ -296,6 +296,14 @@ version 0.1201
   $chords = $mc->cadence;
   # [[67,71,62], [60,64,67,72]]
 
+  $mc = Music::Cadence->new(
+    octave => -1,
+    format => 'midinum',
+  );
+
+  $chords = $mc->cadence;
+  # [[7,11,2], [0,4,7,12]]
+
   $mc = Music::Cadence->new;
 
   $chords = $mc->cadence(
